@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico. 
-   Copyright (C) 1998-2016 Sergey Poznyakoff
+   Copyright (C) 1998-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -356,7 +356,7 @@ sasl_enable(int val)
 }
 
 int
-sasl_enabled_p()
+sasl_enabled_p(void)
 {
     return sasl_enable_state;
 }
@@ -375,7 +375,7 @@ sasl_enable(int val)
 }
 
 int
-sasl_enabled_p()
+sasl_enabled_p(void)
 {
     return 0;
 }
